diff PalanthirServer/DicomIntegerPixelAccessor.cpp @ 50:a15e90e5d6fc

rename in code
author Sebastien Jodogne <s.jodogne@gmail.com>
date Wed, 05 Sep 2012 15:50:12 +0200
parents 33d67e1ab173
children 293038baf8f1
line wrap: on
line diff
--- a/PalanthirServer/DicomIntegerPixelAccessor.cpp	Wed Sep 05 15:38:08 2012 +0200
+++ b/PalanthirServer/DicomIntegerPixelAccessor.cpp	Wed Sep 05 15:50:12 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palantir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -24,12 +24,12 @@
 #define NOMINMAX
 #endif
 
-#include "../Core/PalantirException.h"
+#include "../Core/PalanthirException.h"
 #include "FromDcmtkBridge.h"
 #include <boost/lexical_cast.hpp>
 #include <limits>
 
-namespace Palantir
+namespace Palanthir
 {
   DicomIntegerPixelAccessor::DicomIntegerPixelAccessor(const DicomMap& values,
                                                        const void* pixelData,
@@ -54,30 +54,30 @@
     }
     catch (boost::bad_lexical_cast)
     {
-      throw PalantirException(ErrorCode_NotImplemented);
+      throw PalanthirException(ErrorCode_NotImplemented);
     }
 
     if (bitsAllocated != 8 && bitsAllocated != 16 && 
         bitsAllocated != 24 && bitsAllocated != 32)
     {
-      throw PalantirException(ErrorCode_NotImplemented);
+      throw PalanthirException(ErrorCode_NotImplemented);
     }
 
     if (bitsAllocated > 32 ||
         bitsStored >= 32)
     {
       // Not available, as the accessor internally uses int32_t values
-      throw PalantirException(ErrorCode_NotImplemented);
+      throw PalanthirException(ErrorCode_NotImplemented);
     }
     
     if (samplesPerPixel_ != 1)
     {
-      throw PalantirException(ErrorCode_NotImplemented);
+      throw PalanthirException(ErrorCode_NotImplemented);
     }
 
     if (width_ * height_ * bitsAllocated / 8 != size)
     {
-      throw PalantirException(ErrorCode_NotImplemented);
+      throw PalanthirException(ErrorCode_NotImplemented);
     }
 
     /*printf("%d %d %d %d %d %d %d\n", width_, height_, samplesPerPixel_, bitsAllocated,
@@ -145,7 +145,7 @@
     if (v & signMask_)
     {
       // Signed value: Not implemented yet
-      //throw PalantirException(ErrorCode_NotImplemented);
+      //throw PalanthirException(ErrorCode_NotImplemented);
       v = 0;
     }
@@ -1,5 +1,5 @@
 /**
- * Palantir - A Lightweight, RESTful DICOM Store
+ * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium